@@ -6,13 +6,15 @@ use Dist::Zilla;
 use PerlX::Maybe qw( maybe );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.27'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 use namespace::autoclean;
 
+sub mvp_multivalue_args { qw( alien_build_command alien_install_command ) }
+
 sub configure
 {
   my($self) = @_;
@@ -27,7 +29,19 @@ sub configure
     'ShareDir',
   );
   
-  $self->add_plugins($self->payload->{installer} // 'MakeMaker');
+  my $installer = $self->payload->{installer} // 'MakeMaker';
+  if($installer eq 'Alien')
+  {
+    my %args = 
+      map { $_ => $self->payload->{"alien_$_"} }
+      map { s/^alien_//; $_ } 
+      grep /^alien_/, keys %{ $self->payload };
+    $self->add_plugins([ Alien => \%args ]);
+  }
+  else
+  {
+    $self->add_plugins($installer);
+  }
   
   $self->add_plugins(
     'Manifest',
@@ -109,13 +123,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by Plicease
 
 =head1 VERSION
 
-version 1.27
+version 1.34
 
 =head1 SYNOPSIS
 
@@ -186,6 +202,10 @@ Specify an alternative to L<[MakeMaker]|Dist::Zilla::Plugin::MakeMaker>
 L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny>, or
 L<[ModuleBuildDatabase]|Dist::Zilla::Plugin::ModuleBuildDatabase> for example).
 
+If installer is L<Alien|Dist::Zilla::Plugin::Alien>, then any options 
+with the alien_ prefix will be passed to L<Alien|Dist::Zilla::Plugin::Alien>
+(minus the alien_ prefix).
+
 =head2 readme_from
 
 Which file to pull from for the Readme (must be POD format).  If not 
